close method
Closes the shared transport and all connections owned by it.
Scoped Dio instances must not be closed directly because they all use the same HttpClientAdapter. Call this only when the network layer will no longer be used, such as during application shutdown or test teardown.
Implementation
void close({bool force = false}) {
if (_isClosed) {
return;
}
_isClosed = true;
_rootDio.close(force: force);
}